@@ -5,7 +5,7 @@
  *        optimized implementations of the combinatorial type
  *        prime counting function algorithms.
  *
- * Copyright (C) 2021 Kim Walisch, <kim.walisch@gmail.com>
+ * Copyright (C) 2023 Kim Walisch, <kim.walisch@gmail.com>
  *
  * This file is distributed under the BSD License.
  */
@@ -16,9 +16,9 @@
 #include <stddef.h>
 #include <stdint.h>
 
-#define PRIMECOUNT_VERSION "7.0"
+#define PRIMECOUNT_VERSION "7.8"
 #define PRIMECOUNT_VERSION_MAJOR 7
-#define PRIMECOUNT_VERSION_MINOR 0
+#define PRIMECOUNT_VERSION_MINOR 8
 
 #ifdef __cplusplus
 extern "C" {
@@ -80,16 +80,16 @@ int64_t primecount_nth_prime(int64_t n);
  * The return type is a char* as primecount_get_max_x() may be a
  * 128-bit integer which is not supported by some compilers.
  */
-const char* primecount_get_max_x();
+const char* primecount_get_max_x(void);
 
 /*  Get the currently set number of threads */
-int primecount_get_num_threads();
+int primecount_get_num_threads(void);
 
 /*  Set the number of threads */
 void primecount_set_num_threads(int num_threads);
 
 /* Get the primecount version number, in the form “i.j” */
-const char* primecount_version();
+const char* primecount_version(void);
 
 #ifdef __cplusplus
 } /* extern "C" */
